@@ -2,14 +2,26 @@
 
 echo "Updating translation (*.ts) files"
 
-cd ../../src/
+cd ../../gui/
 
-UI=`find | grep "\.ui"`
-CPP=`find | grep "\.cpp"`
-H=`find | grep "\.h"`
+
+
+if [ "$QTDIR" ]; then
+	LUPDATE="$QTDIR/bin/lupdate"
+	LRELEASE="$QTDIR/bin/lrelease"
+else
+	LUPDATE=$(which lupdate)
+	LRELEASE=$(which lrelease)
+fi;
+
+UI=`find . | grep "\.ui$"`
+CPP=`find . | grep "\.cpp$"`
+H=`find . | grep "\.h$"`
 FILES="$UI $CPP $H"
 
-CMD="lupdate ${FILES} -ts"
+CMD="$LUPDATE -noobsolete ${FILES} -ts"
+
+
 
 $CMD ../data/i18n/hydrogen.it.ts
 $CMD ../data/i18n/hydrogen.es.ts
@@ -21,8 +33,13 @@ $CMD ../data/i18n/hydrogen.pl.ts
 $CMD ../data/i18n/hydrogen.nl.ts
 $CMD ../data/i18n/hydrogen.ja.ts
 $CMD ../data/i18n/hydrogen.de.ts
+$CMD ../data/i18n/hydrogen.sv.ts
+$CMD ../data/i18n/hydrogen.hr.ts
 
 echo "Creating *.qm files"
 cd ../data/i18n
-lrelease *.ts
+$LRELEASE *.ts
 
+
+echo "Stats"
+./stats.py
